@@ -413,7 +413,7 @@ def Heatmap(data, bodyPart, **kwargs):
         cb = fig.colorbar(im,cax=cax, orientation='vertical')
         cb.ax.tick_params(labelsize=fontsize*0.8)
 
-def ScaleConverter(dado, pixel_max,pixel_min,max_real, min_real=0):
+def pixel2centimeters(data, pixel_max,pixel_min,max_real, min_real=0):
     """
     It performs the pixel conversion to the determined real scale (meter, 
     centimeter, millimeter...).
@@ -445,7 +445,7 @@ def ScaleConverter(dado, pixel_max,pixel_min,max_real, min_real=0):
     This function was developed based on DLC outputs and is able to support 
     matplotlib configurations."""    
 
-    return min_real + ((dado-pixel_min)/(pixel_max-pixel_min)) * (max_real-min_real)
+    return min_real + ((data-pixel_min)/(pixel_max-pixel_min)) * (max_real-min_real)
 
 def MotionMetrics (data,bodyPart,filter=1,fps=30,max_real=60,min_real=0):
     """
@@ -489,8 +489,8 @@ def MotionMetrics (data,bodyPart,filter=1,fps=30,max_real=60,min_real=0):
     dataX = values[:,lista1.index(bodyPart+" - x")]
     dataY = values[:,lista1.index(bodyPart+" - y")]
 
-    dataX = ScaleConverter(dataX,dataX.max(),dataX.min(), max_real,0)
-    dataY = ScaleConverter(dataY,dataY.max(),dataY.min(), min_real,0)
+    dataX = pixel2centimeters(dataX,dataX.max(),dataX.min(), max_real,0)
+    dataY = pixel2centimeters(dataY,dataY.max(),dataY.min(), min_real,0)
 
     time = np.arange(0,((1/fps)*len(dataX)), (1/fps))
     df = pd.DataFrame(time/60, columns = ["Time"])
@@ -1680,4 +1680,52 @@ def ClassifyBehavior(data,video, bodyparts_list, dimensions = 2,distance=28,**kw
       return cluster_labels, data_emb, model, data_HDim, knn, knc, cpd
 
     else:
-      return cluster_labels, X_transformed, model, d[startIndex:endIndex]
\ No newline at end of file
+      return cluster_labels, X_transformed, model, d[startIndex:endIndex]
+
+
+def SpacialNeuralActivity(neural_data, unit):
+    """
+    Performs the visualizaton of the neural data on pixel space.
+
+    Parameters
+    ----------
+    neural_data : pandas DataFrame
+        a dataframe with the positions of rat in columns: x, y
+        and the number of spikes for each unit in columns:
+        unit_1, ..., unit_n.
+    unit : int
+        The unit (column) to plot.
+        
+    Returns
+    -------
+    out : heatmap (ndarray)
+        The matrix with spike triggered avarages for selected unit.
+
+    See Also
+    --------
+    For more information and usage examples: https://github.com/pyratlib/pyrat
+
+    Notes
+    -----
+    This function was developed based on Fujisawa et al., 2008 data."""
+
+    import numpy as np
+    import pandas as pd
+    
+    neural_data = neural_data.loc[ neural_data['x'] > 100, : ]
+
+    xmin, xmax = neural_data['x'].min(), neural_data['x'].max()
+    ymin, ymax = neural_data['y'].min(), neural_data['y'].max()
+
+    xsteps = np.linspace(xmin, xmax, num=100)
+    ysteps = np.linspace(ymin, ymax, num=100)
+
+    heatmap = np.zeros( (xsteps.shape[0], ysteps.shape[0]) )
+
+    for x in range(xsteps.shape[0]-1):
+        for y in range(ysteps.shape[0]-1):
+            df_tmp = neural_data.loc[ (neural_data['x'] >= xsteps[x]) & (neural_data['x'] < xsteps[x+1]) &
+                                (neural_data['y'] >= ysteps[y]) & (neural_data['y'] < ysteps[y+1]), : ]
+            heatmap[x, y] = df_tmp[unit].sum()
+            
+    return heatmap
\ No newline at end of file
